# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#          Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Page to list folders in a Ubuntu One account."""

import gettext

from PyQt4 import QtCore, QtGui
from ubuntu_sso.qt.gui import SSOWizardPage
from ubuntuone.controlpanel.gui.qt import folders

from ubuntuone_installer.gui.qt.ui import folders_ui

_ = gettext.gettext


class FoldersPage(SSOWizardPage):
    """Wizard page to list and manage an account's folders."""

    def __init__(self, parent=None):
        super(FoldersPage, self).__init__(folders_ui.Ui_Form(), None, parent)
        self.setTitle(_("Syncing your computer with the cloud"))
        self.folders_widget = folders.FoldersPanel()
        self.layout().insertWidget(
            self.layout().count() - 1, self.folders_widget)
        self.folders_widget.ui.share_publish_button.hide()
        self.folders_widget.ui.add_folder_button.hide()
        self.folders_widget.ui.folders.setHeaderHidden(True)
        self.folders_widget.ui.folders.setColumnHidden(2, True)

    # Invalid name "initializePage"
    # pylint: disable=C0103

    def initializePage(self):
        """Set Folders Page navigation buttons."""
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton1, False)
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton2, False)
        self.wizard().setButtonLayout([
            QtGui.QWizard.BackButton,
            QtGui.QWizard.Stretch,
            QtGui.QWizard.NextButton])
        self.wizard()._next_id = self.wizard().CONGRATULATIONS_PAGE

    # pylint: enable=C0103

    @QtCore.pyqtSlot()
    def on_check_settings_button_clicked(self):
        """Show the Preferences Page when the user click on Settings button."""
        self.wizard()._next_id = \
            self.wizard().preferences_page_id
        self.wizard().next()
