# -*- coding: utf-8 -*-

# Authors: Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the platform specific functions."""

import sys
import os

import win32api

from ubuntuone_installer.gui.qt import utils
from ubuntuone_installer.gui.qt.tests import BaseTestCase


class UninstallerTestCase(BaseTestCase):
    """Test the qt main window."""

    def test_execute_uninstall_on_licence_cancel(self):
        """Pressing Disagree button from license page the uninstall is exec."""
        self.patch(win32api, "ShellExecute", self._set_called)
        utils.uninstall_application()
        # If it's frozen this test fails because the path
        # depends on the location of the exe
        if hasattr(sys, "frozen"):
            delattr(sys, "frozen")
        exec_path = os.path.abspath(__file__)
        folder_path_utils_dir = os.path.dirname(exec_path)
        folder_path_qt_dir = os.path.dirname(folder_path_utils_dir)
        folder = os.path.dirname(folder_path_qt_dir)
        uninstall_path = os.path.join(os.path.dirname(folder), "uninstall.exe")
        self.assertEqual(self._called,
            ((None, 'runas', uninstall_path, '--mode=qt', '', 0), {}))

    def test_execute_uninstall_on_licence_cancel_frozen(self):
        """Pressing Disagree button from license page the uninstall is exec."""
        self.patch(win32api, "ShellExecute", self._set_called)
        sys.frozen = True
        utils.uninstall_application()
        self.assertTrue(self._called[0][0] is None)
        self.assertTrue("uninstall.exe" in self._called[0][2])
        self.assertTrue('runas' == self._called[0][1])
        self.assertTrue('--mode=qt' == self._called[0][3])
        self.assertTrue('' == self._called[0][4])
        self.assertTrue(0 == self._called[0][5])
